==> docassemble.webapp-1.4.25.tar.gz: docassemble.webapp-1.4.25/docassemble/webapp/static/bootstrap-fileinput/themes/fas/theme.js <==
/*!
 * bootstrap-fileinput v5.1.3
 * http://plugins.krajee.com/file-input
 *
 * Font Awesome 5 icon theme configuration for bootstrap-fileinput. Requires font awesome 5 assets to be loaded.
 *
 * Author: Kartik Visweswaran
 * Copyright: 2014 - 2020, Kartik Visweswaran, Krajee.com
 *
 * Licensed under the BSD-3-Clause
 * https://github.com/kartik-v/bootstrap-fileinput/blob/master/LICENSE.md
 */
(function ($) {
  "use strict";

  $.fn.fileinputThemes.fas = {
    fileActionSettings: {
      removeIcon: '<i class="fas fa-trash-alt"></i>',
      uploadIcon: '<i class="fas fa-upload"></i>',
      uploadRetryIcon: '<i class="fas fa-redo-alt"></i>',
      downloadIcon: '<i class="fas fa-download"></i>',
      zoomIcon: '<i class="fas fa-search-plus"></i>',
      dragIcon: '<i class="fas fa-arrows-alt"></i>',
      indicatorNew: '<i class="fas fa-plus-circle text-warning"></i>',
      indicatorSuccess: '<i class="fas fa-check-circle text-success"></i>',
      indicatorError: '<i class="fas fa-exclamation-circle text-danger"></i>',
      indicatorLoading: '<i class="fas fa-hourglass text-muted"></i>',
      indicatorPaused: '<i class="fa fa-pause text-info"></i>',
    },
    layoutTemplates: {
      fileIcon: '<i class="fas fa-file kv-caption-icon"></i> ',
    },
    previewZoomButtonIcons: {
      prev: '<i class="fas fa-caret-left fa-lg"></i>',
      next: '<i class="fas fa-caret-right fa-lg"></i>',
      toggleheader: '<i class="fas fa-fw fa-arrows-alt-v"></i>',
      fullscreen: '<i class="fas fa-fw fa-arrows-alt"></i>',
      borderless: '<i class="fas fa-fw fa-external-link-alt"></i>',
      close: '<i class="fas fa-fw fa-xmark"></i>',
    },
    previewFileIcon: '<i class="fas fa-file"></i>',
    browseIcon: '<i class="fas fa-folder-open"></i>',
    removeIcon: '<i class="fas fa-trash-alt"></i>',
    cancelIcon: '<i class="fas fa-ban"></i>',
    pauseIcon: '<i class="fas fa-pause"></i>',
    uploadIcon: '<i class="fas fa-upload"></i>',
    msgValidationErrorIcon: '<i class="fas fa-exclamation-circle"></i> ',
  };
})(window.jQuery);

==> docassemble.webapp-1.4.66.tar.gz: docassemble.webapp-1.4.66/docassemble/webapp/static/bootstrap-fileinput/themes/fas/theme.js <==
/*!
 * bootstrap-fileinput v5.1.3
 * http://plugins.krajee.com/file-input
 *
 * Font Awesome 5 icon theme configuration for bootstrap-fileinput. Requires font awesome 5 assets to be loaded.
 *
 * Author: Kartik Visweswaran
 * Copyright: 2014 - 2020, Kartik Visweswaran, Krajee.com
 *
 * Licensed under the BSD-3-Clause
 * https://github.com/kartik-v/bootstrap-fileinput/blob/master/LICENSE.md
 */
(function ($) {
  "use strict";

  $.fn.fileinputThemes.fas = {
    fileActionSettings: {
      removeIcon: '<i class="fas fa-trash-alt"></i>',
      uploadIcon: '<i class="fas fa-upload"></i>',
      uploadRetryIcon: '<i class="fas fa-redo-alt"></i>',
      downloadIcon: '<i class="fas fa-download"></i>',
      zoomIcon: '<i class="fas fa-search-plus"></i>',
      dragIcon: '<i class="fas fa-arrows-alt"></i>',
      indicatorNew: '<i class="fas fa-plus-circle text-warning"></i>',
      indicatorSuccess: '<i class="fas fa-check-circle text-success"></i>',
      indicatorError: '<i class="fas fa-exclamation-circle text-danger"></i>',
      indicatorLoading: '<i class="fas fa-hourglass text-body-secondary"></i>',
      indicatorPaused: '<i class="fa fa-pause text-info"></i>',
    },
    layoutTemplates: {
      fileIcon: '<i class="fas fa-file kv-caption-icon"></i> ',
    },
    previewZoomButtonIcons: {
      prev: '<i class="fas fa-caret-left fa-lg"></i>',
      next: '<i class="fas fa-caret-right fa-lg"></i>',
      toggleheader: '<i class="fas fa-fw fa-arrows-alt-v"></i>',
      fullscreen: '<i class="fas fa-fw fa-arrows-alt"></i>',
      borderless: '<i class="fas fa-fw fa-external-link-alt"></i>',
      close: '<i class="fas fa-fw fa-xmark"></i>',
    },
    previewFileIcon: '<i class="fas fa-file"></i>',
    browseIcon: '<i class="fas fa-folder-open"></i>',
    removeIcon: '<i class="fas fa-trash-alt"></i>',
    cancelIcon: '<i class="fas fa-ban"></i>',
    pauseIcon: '<i class="fas fa-pause"></i>',
    uploadIcon: '<i class="fas fa-upload"></i>',
    msgValidationErrorIcon: '<i class="fas fa-exclamation-circle"></i> ',
  };
})(window.jQuery);
